==> apollo_sdk-0.1.3-py3-none-any.whl: apollo/database/supabase/cloud.py <==
# Copyright 2022 Adrian Brown
# Copyright 2023 Apollo API, Inc.
#
#    Licensed under the Elastic License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         https://www.elastic.co/licensing/elastic-license
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import psycopg as pgi_connector
import psycopg2
import psycopg2.extras

from .base import AbstractSupabaseClient
from apollo.exceptions import PostgresConnectionError, PostgresExecutionError
from ..


class SupabaseClient(AbstractSupabaseClient):
    def __init__(self, connection_string: str):
        self.secret = connection_string

    def execute(self, sql):
        if not self.secret:
            raise PostgresExecutionError("empty secret")

        try:
            conn_dict = pgi_connector.conninfo.conninfo_to_dict(self.secret)
            con = psycopg2.connect(**conn_dict)
        except Exception as err:
            raise PostgresConnectionError(err)

        response = None
        with con:

            cursor = con.cursor(cursor_factory=psycopg2.extras.DictCursor)
            cursor.execute(str(sql))

            response = cursor.fetchall()

        return response

==> apollo_sdk-0.2.11-py3-none-any.whl: apollo/database/supabase/cloud.py <==
# Copyright 2023 Apollo API, Inc.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import psycopg as pgi_connector
import psycopg2
import psycopg2.extras

from apollo.database.supabase.base import AbstractSupabaseClient
from apollo.exceptions import PostgresConnectionError, PostgresExecutionError


class SupabaseClient(AbstractSupabaseClient):
    def __init__(self, connection_string: str):
        self.secret = connection_string

    def execute(self, sql):
        if not self.secret:
            raise PostgresExecutionError("empty secret")

        try:
            conn_dict = pgi_connector.conninfo.conninfo_to_dict(self.secret)
            con = psycopg2.connect(**conn_dict)
        except Exception as err:
            raise PostgresConnectionError(err)

        response = None
        with con:

            cursor = con.cursor(cursor_factory=psycopg2.extras.DictCursor)
            cursor.execute(str(sql))

            response = cursor.fetchall()

        return response
